@@ -69,8 +69,6 @@ protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
-    void changeGlobalIconSizeSetting(int, int);
-    void deleteGlobalIconSizeSetting();
     void changeGlobalToolButtonStyleSetting(const QString &, const QString &);
     void deleteGlobalToolButtonStyleSetting();
     QByteArray m_xml;
@@ -105,7 +103,7 @@ void tst_KToolBar::initTestCase()
     testDataDir.mkpath(QStringLiteral("."));
 
     // setup action restriction so we can test whether this actually disables some functionality
-    KConfigGroup actionRestrictions(KSharedConfig::openConfig(), "KDE Action Restrictions");
+    KConfigGroup actionRestrictions(KSharedConfig::openConfig(), QStringLiteral("KDE Action Restrictions"));
     actionRestrictions.writeEntry("action/options_show_toolbar", false);
 
     // copy a minimal icon theme to where KIconTheme will find it, in case oxygen-icons is not
@@ -164,7 +162,6 @@ void tst_KToolBar::init()
 void tst_KToolBar::cleanup()
 {
     QFile::remove(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QStringLiteral("/tst_KToolBar"));
-    deleteGlobalIconSizeSetting();
     deleteGlobalToolButtonStyleSetting();
 }
 
@@ -194,7 +191,7 @@ void tst_KToolBar::testIconSizeNoXmlGui()
 {
     QFETCH(int, iconSize);
     KConfig config(QStringLiteral("tst_KToolBar"));
-    KConfigGroup group(&config, "group");
+    KConfigGroup group(&config, QStringLiteral("group"));
     {
         KMainWindow kmw;
         KToolBar *mainToolBar = kmw.toolBar(QStringLiteral("mainToolBar"));
@@ -216,10 +213,10 @@ void tst_KToolBar::testIconSizeNoXmlGui()
         // was it the default value?
         if (iconSize == KIconLoader::global()->currentSize(KIconLoader::MainToolbar)) {
             QCOMPARE(group.groupList().count(), 0); // nothing to save
-            QVERIFY(!group.group("Toolbar mainToolBar").hasKey("IconSize"));
+            QVERIFY(!group.group(QStringLiteral("Toolbar mainToolBar")).hasKey("IconSize"));
         } else {
             QCOMPARE(group.groupList().count(), 2); // two subgroups (one for each toolbar)
-            QVERIFY(group.group("Toolbar mainToolBar").hasKey("IconSize"));
+            QVERIFY(group.group(QStringLiteral("Toolbar mainToolBar")).hasKey("IconSize"));
         }
     }
 
@@ -236,57 +233,25 @@ void tst_KToolBar::testIconSizeNoXmlGui()
         QCOMPARE(mainToolBar->iconSize().width(), iconSize);
         QCOMPARE(otherToolBar->iconSize().width(), iconSize);
         QCOMPARE(cleanToolBar->iconSize().width(), KIconLoader::global()->currentSize(KIconLoader::Toolbar)); // unchanged
-        const bool mainToolBarWasUsingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
-        const bool otherToolBarWasUsingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::Toolbar);
-
-#ifndef Q_OS_WIN // the change notification uses DBus
-        // Now emulate a change of the kde-global setting (#168480#c12)
-        changeGlobalIconSizeSetting(32, 33);
-
-        QCOMPARE(KIconLoader::global()->currentSize(KIconLoader::MainToolbar), 32);
-        QCOMPARE(KIconLoader::global()->currentSize(KIconLoader::Toolbar), 33);
-
-        if (mainToolBarWasUsingDefaultSize) {
-            QCOMPARE(mainToolBar->iconSize().width(), 32);
-        } else { // the user chose a specific size for the toolbar, so the new global size isn't used
-            QCOMPARE(mainToolBar->iconSize().width(), iconSize);
-        }
-        if (otherToolBarWasUsingDefaultSize) {
-            QCOMPARE(otherToolBar->iconSize().width(), 33);
-        } else { // the user chose a specific size for the toolbar, so the new global size isn't used
-            QCOMPARE(otherToolBar->iconSize().width(), iconSize);
-        }
-        QCOMPARE(cleanToolBar->iconSize().width(), 33);
-#endif
     }
 }
 
 void tst_KToolBar::testIconSizeXmlGui_data()
 {
     QTest::addColumn<int>("iconSize"); // set by user and saved to KConfig
-    QTest::addColumn<int>("expectedSizeMainToolbar"); // ... after kde-global is changed to 25
-    QTest::addColumn<int>("expectedSizeOtherToolbar"); // ... after kde-global is changed to 16
-    QTest::addColumn<int>("expectedSizeCleanToolbar"); // ... after kde-global is changed to 16
-    QTest::addColumn<int>("expectedSizeBigToolbar"); // ... after kde-global is changed to 16
     // When the user chose a specific size for the toolbar (!= its default size), the new kde-global size isn't applied to that toolbar.
     // So, only in case the toolbar was at iconSize already, and there was no setting in xml, we end up with kdeGlobal being used:
-    const int kdeGlobalMain = 25;
-    const int kdeGlobalOther = 16;
-    QTest::newRow("16") << 16 << 16 << 16 << kdeGlobalOther << 16;
-    QTest::newRow("22") << 22 << kdeGlobalMain << kdeGlobalOther << kdeGlobalOther << 22;
-    QTest::newRow("32") << 32 << 32 << 32 << kdeGlobalOther << 32;
-    QTest::newRow("64") << 64 << 64 << 64 << kdeGlobalOther << 64;
+    QTest::newRow("16") << 16;
+    QTest::newRow("22") << 22;
+    QTest::newRow("32") << 32;
+    QTest::newRow("64") << 64;
 }
 
 void tst_KToolBar::testIconSizeXmlGui()
 {
     QFETCH(int, iconSize);
-    QFETCH(int, expectedSizeMainToolbar);
-    QFETCH(int, expectedSizeOtherToolbar);
-    QFETCH(int, expectedSizeCleanToolbar);
-    QFETCH(int, expectedSizeBigToolbar);
     KConfig config(QStringLiteral("tst_KToolBar"));
-    KConfigGroup group(&config, "group");
+    KConfigGroup group(&config, QStringLiteral("group"));
     {
         TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
         kmw.createActions(QStringList() << QStringLiteral("go_up"));
@@ -318,55 +283,13 @@ void tst_KToolBar::testIconSizeXmlGui()
         const bool usingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
         if (usingDefaultSize) {
             QVERIFY(!group.groupList().contains(QLatin1String("Toolbar mainToolBar")));
-            QVERIFY(!group.group("Toolbar mainToolBar").hasKey("IconSize"));
+            QVERIFY(!group.group(QStringLiteral("Toolbar mainToolBar")).hasKey("IconSize"));
         } else {
-            QVERIFY(group.group("Toolbar mainToolBar").hasKey("IconSize"));
+            QVERIFY(group.group(QStringLiteral("Toolbar mainToolBar")).hasKey("IconSize"));
         }
-
-#ifndef Q_OS_WIN // the change notification uses DBus
-        // Now emulate a change of the kde-global setting (#168480#c12)
-        changeGlobalIconSizeSetting(25, 16);
-
-        QCOMPARE(mainToolBar->iconSize().width(), expectedSizeMainToolbar);
-        QCOMPARE(otherToolBar->iconSize().width(), expectedSizeOtherToolbar);
-        QCOMPARE(cleanToolBar->iconSize().width(), expectedSizeCleanToolbar);
-        QCOMPARE(bigToolBar->iconSize().width(), expectedSizeBigToolbar);
-#endif
-
-        // The big unchanged toolbar should be, well, unchanged; AppXml has priority over KDE_Default.
-        QCOMPARE(bigUnchangedToolBar->iconSize().width(), 32);
     }
 }
 
-void tst_KToolBar::changeGlobalIconSizeSetting(int mainToolbarIconSize, int iconSize)
-{
-    // We could use KConfig::Normal|KConfig::Global here, to write to kdeglobals like kcmstyle does,
-    // but we don't need to. Writing to the app's config file works too.
-    KConfigGroup mglobals(KSharedConfig::openConfig(), "MainToolbarIcons");
-    mglobals.writeEntry("Size", mainToolbarIconSize);
-    KConfigGroup globals(KSharedConfig::openConfig(), "ToolbarIcons");
-    // globals.writeEntry("Size", iconSize, KConfig::Normal|KConfig::Global);
-    globals.writeEntry("Size", iconSize);
-    KSharedConfig::openConfig()->sync();
-
-    QSignalSpy spy(KIconLoader::global(), &KIconLoader::iconChanged);
-    KIconLoader::global()->emitChange(KIconLoader::Desktop);
-    spy.wait(200);
-}
-
-void tst_KToolBar::deleteGlobalIconSizeSetting()
-{
-    KConfigGroup mglobals(KSharedConfig::openConfig(), "MainToolbarIcons");
-    mglobals.deleteEntry("Size");
-    KConfigGroup globals(KSharedConfig::openConfig(), "ToolbarIcons");
-    globals.deleteEntry("Size");
-    KSharedConfig::openConfig()->sync();
-
-    QSignalSpy spy(KIconLoader::global(), &KIconLoader::iconChanged);
-    KIconLoader::global()->emitChange(KIconLoader::Desktop);
-    spy.wait(200);
-}
-
 Q_DECLARE_METATYPE(Qt::ToolButtonStyle)
 
 void tst_KToolBar::testToolButtonStyleNoXmlGui_data()
@@ -386,7 +309,7 @@ void tst_KToolBar::testToolButtonStyleNoXmlGui()
     const bool selectedDefaultForOtherToolbar = toolButtonStyle == Qt::ToolButtonTextBesideIcon;
 
     KConfig config(QStringLiteral("tst_KToolBar"));
-    KConfigGroup group(&config, "group");
+    KConfigGroup group(&config, QStringLiteral("group"));
     {
         KMainWindow kmw;
         KToolBar *mainToolBar = kmw.toolBar(QStringLiteral("mainToolBar"));
@@ -405,10 +328,10 @@ void tst_KToolBar::testToolButtonStyleNoXmlGui()
         kmw.saveMainWindowSettings(group);
         if (selectedDefaultForMainToolbar) {
             QCOMPARE(group.groupList().count(), 0); // nothing to save
-            QVERIFY(!group.group("Toolbar mainToolBar").hasKey("ToolButtonStyle"));
+            QVERIFY(!group.group(QStringLiteral("Toolbar mainToolBar")).hasKey("ToolButtonStyle"));
         } else {
             QCOMPARE(group.groupList().count(), 2); // two subgroups (one for each toolbar)
-            QVERIFY(group.group("Toolbar mainToolBar").hasKey("ToolButtonStyle"));
+            QVERIFY(group.group(QStringLiteral("Toolbar mainToolBar")).hasKey("ToolButtonStyle"));
         }
     }
 
@@ -466,7 +389,7 @@ void tst_KToolBar::testToolButtonStyleXmlGui()
     QFETCH(Qt::ToolButtonStyle, expectedStyleCleanToolbar);
     const Qt::ToolButtonStyle mainToolBarDefaultStyle = Qt::ToolButtonTextBesideIcon; // was TextUnderIcon before KDE-4.4.0
     KConfig config(QStringLiteral("tst_KToolBar"));
-    KConfigGroup group(&config, "group");
+    KConfigGroup group(&config, QStringLiteral("group"));
     {
         TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
         kmw.createActions(QStringList() << QStringLiteral("go_up"));
@@ -499,7 +422,7 @@ void tst_KToolBar::testToolButtonStyleXmlGui()
 
 void tst_KToolBar::changeGlobalToolButtonStyleSetting(const QString &mainToolBar, const QString &otherToolBars)
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "Toolbar style");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("Toolbar style"));
     group.writeEntry("ToolButtonStyle", mainToolBar);
     group.writeEntry("ToolButtonStyleOtherToolbars", otherToolBars);
     group.sync();
@@ -521,7 +444,7 @@ void tst_KToolBar::changeGlobalToolButtonStyleSetting(const QString &mainToolBar
 
 void tst_KToolBar::deleteGlobalToolButtonStyleSetting()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "Toolbar style");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("Toolbar style"));
     group.deleteEntry("ToolButtonStyle");
     group.deleteEntry("ToolButtonStyleOtherToolbars");
     KSharedConfig::openConfig()->sync();
@@ -598,18 +521,13 @@ void tst_KToolBar::testXmlGuiSwitching()
     QCOMPARE(hiddenToolBar->isHidden(), false);
     QCOMPARE(secondHiddenToolBar->isHidden(), true);
 
-    // Now change KDE-global setting, what happens to unsaved changes?
-    changeGlobalIconSizeSetting(32, 33);
-    QCOMPARE(bigToolBar->iconSize().width(), 35); // fine now, saved or unsaved makes no difference
-    QCOMPARE(otherToolBar->iconSize().width(), 35);
-
     // Now save, and check what we saved
     KConfig config(QStringLiteral("tst_KToolBar"));
-    KConfigGroup group(&config, "group");
+    KConfigGroup group(&config, QStringLiteral("group"));
     kmw.saveMainWindowSettings(group);
-    QCOMPARE(group.group("Toolbar bigToolBar").readEntry("IconSize", 0), 35);
-    QCOMPARE(group.group("Toolbar otherToolBar").readEntry("IconSize", 0), 35);
-    QVERIFY(!group.group("Toolbar cleanToolBar").hasKey("IconSize"));
+    QCOMPARE(group.group(QStringLiteral("Toolbar bigToolBar")).readEntry("IconSize", 0), 35);
+    QCOMPARE(group.group(QStringLiteral("Toolbar otherToolBar")).readEntry("IconSize", 0), 35);
+    QVERIFY(!group.group(QStringLiteral("Toolbar cleanToolBar")).hasKey("IconSize"));
     // QCOMPARE(group.group("Toolbar bigToolBar").readEntry("Hidden", false), true);
     // QVERIFY(!group.group("Toolbar cleanToolBar").hasKey("Hidden"));
     // QVERIFY(!group.group("Toolbar hiddenToolBar").hasKey("Hidden"));
