@@ -50,13 +50,11 @@ static bool actionHasGlobalShortcut(const QAction *action)
 class KActionCollectionPrivate
 {
 public:
-    KActionCollectionPrivate()
-        : m_parentGUIClient(nullptr)
-        , configGroup(QStringLiteral("Shortcuts"))
+    KActionCollectionPrivate(KActionCollection *qq)
+        : q(qq)
         , configIsGlobal(false)
         , connectTriggered(false)
         , connectHovered(false)
-        , q(nullptr)
 
     {
     }
@@ -87,16 +85,16 @@ public:
     QMap<QString, QAction *> actionByName;
     QList<QAction *> actions;
 
-    const KXMLGUIClient *m_parentGUIClient;
+    KActionCollection *q = nullptr;
 
-    QString configGroup;
+    const KXMLGUIClient *m_parentGUIClient = nullptr;
+
+    QString configGroup{QStringLiteral("Shortcuts")};
     bool configIsGlobal : 1;
 
     bool connectTriggered : 1;
     bool connectHovered : 1;
 
-    KActionCollection *q;
-
     QList<QWidget *> associatedWidgets;
 };
 
@@ -104,9 +102,8 @@ QList<KActionCollection *> KActionCollectionPrivate::s_allCollections;
 
 KActionCollection::KActionCollection(QObject *parent, const QString &cName)
     : QObject(parent)
-    , d(new KActionCollectionPrivate)
+    , d(new KActionCollectionPrivate(this))
 {
-    d->q = this;
     KActionCollectionPrivate::s_allCollections.append(this);
 
     setComponentName(cName);
@@ -114,9 +111,8 @@ KActionCollection::KActionCollection(QObject *parent, const QString &cName)
 
 KActionCollection::KActionCollection(const KXMLGUIClient *parent)
     : QObject(nullptr)
-    , d(new KActionCollectionPrivate)
+    , d(new KActionCollectionPrivate(this))
 {
-    d->q = this;
     KActionCollectionPrivate::s_allCollections.append(this);
 
     d->m_parentGUIClient = parent;
@@ -363,9 +359,6 @@ QAction *KActionCollection::takeAction(QAction *action)
 
     action->disconnect(this);
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-    Q_EMIT removed(action); // deprecated
-#endif
     Q_EMIT changed();
     return action;
 }
@@ -399,13 +392,13 @@ QAction *KActionCollection::addAction(const QString &name, const QObject *receiv
     return addAction(name, a);
 }
 
-QKeySequence KActionCollection::defaultShortcut(QAction *action) const
+QKeySequence KActionCollection::defaultShortcut(QAction *action)
 {
     const QList<QKeySequence> shortcuts = defaultShortcuts(action);
     return shortcuts.isEmpty() ? QKeySequence() : shortcuts.first();
 }
 
-QList<QKeySequence> KActionCollection::defaultShortcuts(QAction *action) const
+QList<QKeySequence> KActionCollection::defaultShortcuts(QAction *action)
 {
     return action->property("defaultShortcuts").value<QList<QKeySequence>>();
 }
@@ -421,7 +414,7 @@ void KActionCollection::setDefaultShortcuts(QAction *action, const QList<QKeySeq
     action->setProperty("defaultShortcuts", QVariant::fromValue(shortcuts));
 }
 
-bool KActionCollection::isShortcutsConfigurable(QAction *action) const
+bool KActionCollection::isShortcutsConfigurable(QAction *action)
 {
     // Considered as true by default
     const QVariant value = action->property("isShortcutConfigurable");
@@ -719,24 +712,20 @@ void KActionCollection::slotActionTriggered()
     }
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-void KActionCollection::slotActionHighlighted()
-{
-    slotActionHovered();
-}
-#endif
-
 void KActionCollection::slotActionHovered()
 {
     QAction *action = qobject_cast<QAction *>(sender());
     if (action) {
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-        Q_EMIT actionHighlighted(action);
-#endif
         Q_EMIT actionHovered(action);
     }
 }
 
+// The downcast from a QObject to a QAction triggers UBSan
+// but we're only comparing pointers, so UBSan shouldn't check vptrs
+// Similar to https://github.com/itsBelinda/plog/pull/1/files
+#if defined(__clang__) || __GNUC__ >= 8
+__attribute__((no_sanitize("vptr")))
+#endif
 void KActionCollectionPrivate::_k_actionDestroyed(QObject *obj)
 {
     // obj isn't really a QAction anymore. So make sure we don't do fancy stuff
@@ -747,10 +736,6 @@ void KActionCollectionPrivate::_k_actionDestroyed(QObject *obj)
         return;
     }
 
-    // HACK the object we emit is partly destroyed
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-    Q_EMIT q->removed(action);
-#endif
     Q_EMIT q->changed();
 }
 
@@ -760,11 +745,7 @@ void KActionCollection::connectNotify(const QMetaMethod &signal)
         return;
     }
 
-    if (
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-        signal.methodSignature() == "actionHighlighted(QAction*)" ||
-#endif
-        signal.methodSignature() == "actionHovered(QAction*)") {
+    if (signal.methodSignature() == "actionHovered(QAction*)") {
         if (!d->connectHovered) {
             d->connectHovered = true;
             for (QAction *action : std::as_const(d->actions)) {
