@@ -70,6 +70,8 @@ KXMLGUIClient::KXMLGUIClient()
 KXMLGUIClient::KXMLGUIClient(KXMLGUIClient *parent)
     : d(new KXMLGUIClientPrivate)
 {
+    Q_INIT_RESOURCE(kxmlgui);
+
     parent->insertChildClient(this);
 }
 
@@ -98,12 +100,12 @@ KXMLGUIClient::~KXMLGUIClient()
     delete d;
 }
 
-QAction *KXMLGUIClient::action(const char *name) const
+QAction *KXMLGUIClient::action(const QString &name) const
 {
-    QAction *act = actionCollection()->action(QLatin1String(name));
+    QAction *act = actionCollection()->action(name);
     if (!act) {
         for (KXMLGUIClient *client : std::as_const(d->m_children)) {
-            act = client->actionCollection()->action(QLatin1String(name));
+            act = client->actionCollection()->action(name);
             if (act) {
                 break;
             }
@@ -184,7 +186,7 @@ QString KXMLGUIClient::standardsXmlFileLocation()
     if (QStandardPaths::isTestModeEnabled()) {
         return QStringLiteral(":/kxmlgui5/ui_standards.rc");
     }
-    QString file = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("ui/ui_standards.rc"));
+    QString file = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("kxmlgui5/ui_standards.rc"));
     if (file.isEmpty()) {
         // fallback to resource, to allow to use the rc file compiled into this framework, must exist!
         file = QStringLiteral(":/kxmlgui5/ui_standards.rc");
@@ -217,23 +219,13 @@ void KXMLGUIClient::setXMLFile(const QString &_file, bool merge, bool setXMLDoc)
         const QString filter = componentName() + QLatin1Char('/') + _file;
 
         // files on filesystem
-        allFiles << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("kxmlgui5/") + filter); // KF >= 5.1
+        allFiles << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kxmlgui5/") + filter);
 
-        // KF >= 5.4 (resource file)
+        // built-in resource file
         const QString qrcFile(QLatin1String(":/kxmlgui5/") + filter);
         if (QFile::exists(qrcFile)) {
             allFiles << qrcFile;
         }
-
-        // then compat locations
-        const QStringList compatFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, filter) + // kdelibs4, KF 5.0
-            QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, _file); // kdelibs4, KF 5.0, caller passes component name
-
-        if (allFiles.isEmpty() && !compatFiles.isEmpty()) {
-            qCWarning(DEBUG_KXMLGUI) << "KXMLGUI file found at deprecated location" << compatFiles
-                                     << "-- please use ${KDE_INSTALL_KXMLGUI5DIR} to install this file instead.";
-        }
-        allFiles += compatFiles;
     }
     if (allFiles.isEmpty() && !_file.isEmpty()) {
         // if a non-empty file gets passed and we can't find it,
@@ -306,24 +298,24 @@ static void propagateTranslationDomain(QDomDocument &doc, const QStringList &tag
 void KXMLGUIClient::setXML(const QString &document, bool merge)
 {
     QDomDocument doc;
-    QString errorMsg;
-    int errorLine = 0;
-    int errorColumn = 0;
     // QDomDocument raises a parse error on empty document, but we accept no app-specific document,
     // in which case you only get ui_standards.rc layout.
-    bool result = document.isEmpty() || doc.setContent(document, &errorMsg, &errorLine, &errorColumn);
-    if (result) {
-        propagateTranslationDomain(doc, d->m_textTagNames);
-        setDOMDocument(doc, merge);
-    } else {
+    if (!document.isEmpty()) {
+        const QDomDocument::ParseResult result = doc.setContent(document);
+        if (!result) {
+            qCCritical(DEBUG_KXMLGUI) << "Error parsing XML document:" << result.errorMessage << "at line" << result.errorLine << "column"
+                                      << result.errorColumn;
 #ifdef NDEBUG
-        qCCritical(DEBUG_KXMLGUI) << "Error parsing XML document:" << errorMsg << "at line" << errorLine << "column" << errorColumn;
-        setDOMDocument(QDomDocument(), merge); // otherwise empty menus from ui_standards.rc stay around
+            setDOMDocument(QDomDocument(), merge); // otherwise empty menus from ui_standards.rc stay around
 #else
-        qCCritical(DEBUG_KXMLGUI) << "Error parsing XML document:" << errorMsg << "at line" << errorLine << "column" << errorColumn;
-        abort();
+            abort();
 #endif
+            return;
+        }
     }
+
+    propagateTranslationDomain(doc, d->m_textTagNames);
+    setDOMDocument(doc, merge);
 }
 
 void KXMLGUIClient::setDOMDocument(const QDomDocument &document, bool merge)
@@ -595,6 +587,8 @@ bool KXMLGUIClientPrivate::isEmptyContainer(const QDomElement &base, KActionColl
 
 QDomElement KXMLGUIClientPrivate::findMatchingElement(const QDomElement &base, const QDomElement &additive)
 {
+    const QString idAttribute(base.tagName() == QLatin1String("ActionProperties") ? QStringLiteral("scheme") : QStringLiteral("name"));
+
     QDomNode n = additive.firstChild();
     while (!n.isNull()) {
         QDomElement e = n.toElement();
@@ -612,7 +606,7 @@ QDomElement KXMLGUIClientPrivate::findMatchingElement(const QDomElement &base, c
 
         // now see if our tags are equivalent
         if (equalstr(tag, base.tagName()) //
-            && e.attribute(QStringLiteral("name")) == base.attribute(QStringLiteral("name"))) {
+            && e.attribute(idAttribute) == base.attribute(idAttribute)) {
             return e;
         }
     }
